==> ccpem-1.4.1-linux-x86_64.tar.gz: ccpem-1.4.1/lib/py2/pyrvapi_ext/parsers/demo/env.sh <==

test _ != _${CCP4} || . /Applications/Xtal70/ccp4-7.0/bin/ccp4.setup-sh

server_top_uri=http://localhost:8888            # h
server_top_path=${CCP4}                         # h

server_top_uri=                                 # f
server_top_path=                                # f

#
#   | jsrview | safari  | smonkey | firefox |
# h | OK      | OK      | OK      | OK      |
# f | OK      | -       | OK      | OK(*)   |
#
# (*) Firefox > Preferences > Privacy & Security: Never remember history
#

get_uri() {
  rel_path=${1#${server_top_path}}
  test ${server_top_path}${rel_path} = ${1}
  printf ${server_top_uri}/${rel_path}
  unset rel_path
}

script_dir=$(cd $(dirname ${0}); pwd)
if test _ = _${server_top_uri} || test _ = _${server_top_path}; then
  html=${script_dir}/${rep}/index.html
  unset DIRJSRVIEW
else
  html=$(get_uri ${script_dir})/${rep}/index.html
  export DIRJSRVIEW=$(get_uri ${CCP4})/share/jsrview
fi

unset server_top_uri
unset server_top_path
unset script_dir

open_after() {
  sleep ${1}
  /Applications/Xtal70/ccp4-7.0/libexec/jsrview ${html} 2>/dev/null &
  open -g -a /Applications/Firefox.app ${html}
  open -g -a /Applications/SeaMonkey.app ${html}
  test _ = _${DIRJSRVIEW} || open -g -a /Applications/Safari.app ${html}
}

# --------------------- 2 or 3 -------------------
pycmd=ccp4-python
PYTHONPATH=${CCP4}/lib/py2
# pycmd=python3
# PYTHONPATH=/Users/andrey/Xtal/Downloads/Bazaar/rvapi/devel/python
# ------------------------------------------------

export PYTHONPATH=$(cd ../../..; pwd):${PYTHONPATH}
pyexe=$(${pycmd} -c 'import sys; sys.stdout.write(sys.executable)')

==> ccpem-1.5.0-linux-x86_64.tar.gz: ccpem-1.5.0/lib/py2/pyrvapi_ext/parsers/demo/env.sh <==

test _ != _${CCP4} || . /Applications/Xtal70/ccp4-7.0/bin/ccp4.setup-sh

server_top_uri=http://localhost:8888            # h
server_top_path=${CCP4}                         # h

server_top_uri=                                 # f
server_top_path=                                # f

#
#   | jsrview | safari  | smonkey | firefox |
# h | OK      | OK      | OK      | OK      |
# f | OK      | -       | OK      | OK(*)   |
#
# (*) Firefox > Preferences > Privacy & Security: Never remember history
#

get_uri() {
  rel_path=${1#${server_top_path}}
  test ${server_top_path}${rel_path} = ${1}
  printf ${server_top_uri}/${rel_path}
  unset rel_path
}

script_dir=$(cd $(dirname ${0}); pwd)
if test _ = _${server_top_uri} || test _ = _${server_top_path}; then
  html=${script_dir}/${rep}/index.html
  unset DIRJSRVIEW
else
  html=$(get_uri ${script_dir})/${rep}/index.html
  export DIRJSRVIEW=$(get_uri ${CCP4})/share/jsrview
fi

unset server_top_uri
unset server_top_path
unset script_dir

open_after() {
  sleep ${1}
  /Applications/Xtal70/ccp4-7.0/libexec/jsrview ${html} 2>/dev/null &
  test _ = _${DIRJSRVIEW} || open -g -a /Applications/Firefox.app ${html}
  open -g -a /Applications/SeaMonkey.app ${html}
  test _ = _${DIRJSRVIEW} || open -g -a /Applications/Safari.app ${html}
}

# --------------------- 2 or 3 -------------------
pycmd=ccp4-python
PYTHONPATH=${CCP4}/lib/py2
# pycmd=python3
# PYTHONPATH=/Users/andrey/Xtal/Downloads/Bazaar/rvapi/devel/python
# ------------------------------------------------

export PYTHONPATH=$(cd ../../..; pwd):${PYTHONPATH}
pyexe=$(${pycmd} -c 'import sys; sys.stdout.write(sys.executable)')
